@@ -3,9 +3,8 @@
 ###
 
 #  crsMerc =CRS("+init=epsg:3857") # mercator projection
-crsMerc = CRS("+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +no_defs")
-# crsLL = CRS("+epsg:4326")
-
+crsMerc = CRS("+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +ellps=sphere +units=m +nadgrids=@null +no_defs")
+# CRS("+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +wktext +no_defs")
 
 .tile2boundingBox <- function(x,y,zoom){
 
@@ -85,7 +84,7 @@ getTilePaths <- function(xlim,ylim,zoom,path){
   return(tileData)
 }
 
-getTiles <- function(xlim,ylim,zoom,path,maxTiles = 16,
+getTiles <- function(xlim,ylim,zoom,path,
 		cacheDir=tempdir(),
 		timeOut=5*24*60*60,verbose=FALSE){
 	if(verbose) {
@@ -93,10 +92,6 @@ getTiles <- function(xlim,ylim,zoom,path,maxTiles = 16,
 	}
   
    
-	nt = nTiles(xlim,ylim,zoom)
-  if(nt > maxTiles){
-    stop("Cant get ",nt," tiles with maxTiles set to ",maxTiles)
-  }
   tileData = getTilePaths(xlim,ylim,zoom,path)
   localStore = FALSE
   if(file.exists(path)){
@@ -166,7 +161,7 @@ getTiles <- function(xlim,ylim,zoom,path,maxTiles = 16,
 	} # end not rtry error
 
 	
-	}
+	} # end loop ip
 
 	if(length(rasters) > 1) {
 		thenames = names(rasters[[1]])
@@ -184,6 +179,10 @@ getTiles <- function(xlim,ylim,zoom,path,maxTiles = 16,
 		rasters@legend@colortable = newtable
 		values(rasters) = tomatch[values(rasters)+1]-1
 	}
+  attributes(rasters)$tiles = 
+      list(tiles = length(tileData), 
+          zoom=zoom,
+          path=path)
 	
 	return(rasters)	
 	
