@@ -15,14 +15,15 @@ points(myPoints)
 if(require('rgdal', quietly=TRUE)) {
 	
 
-utmproj = "+proj=utm +zone=32" 
+  # utm zone 32
+utmproj = "+init=epsg:3064" 
 myrasterUTM = projectRaster(myraster, crs=utmproj)
 myPointsUTM = spTransform(myPoints, CRS(utmproj))
 plot(myrasterUTM)
 points(myPointsUTM)
 
 myPointsMercator = spTransform(myPoints, 
-		CRS("+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m"))
+		CRS("+init=epsg:3857"))
 
 
 myplot = function(first,second=first) {
@@ -97,7 +98,7 @@ if(exists("nsl", where="package:utils")) {
 		myplot(myPointsUTM)
 		
 		# specify different output crs
-	mytiles = openmap(myPointsUTM, crs="+proj=longlat")
+	mytiles = openmap(myPointsUTM, crs="+init=epsg:4326")
 #	mycities = GNcities(myPoints,max=5)
 	myplot(myPoints)
 
